| Title: | Chinese Character Frequency in Real World |
|---|---|
| Description: | It contains Chinese character frequency data based on news data from 2017 to 2019. |
| Authors: | Yitao Ma [aut, cre], Xinjin Zhang [aut], Bin Cui [aut] |
| Maintainer: | Yitao Ma <[email protected]> |
| License: | CC0 |
| Version: | 0.1 |
| Built: | 2026-05-27 08:44:24 UTC |
| Source: | https://github.com/schirp/rwstats |
This dataframe inclues the usage frequecy and occurence of Chinese word
fiveCharfiveChar
A data frame with 3 variables:
charactertarget character
freqoccurence of target character
pctfrequency of target character
fiveCharfiveChar
This dataframe inclues the usage frequecy and occurence of Chinese word
fourCharfourChar
A data frame with 3 variables:
charactertarget character
freqoccurence of target character
pctfrequency of target character
fourCharfourChar
This dataframe inclues the usage frequecy and occurence of Chinese word
oneCharoneChar
A data frame with 3 variables:
charactertarget character
freqoccurence of target character
pctfrequency of target character
oneCharoneChar
This dataframe inclues the usage frequecy and occurence of Chinese word
threeCharthreeChar
A data frame with 3 variables:
charactertarget character
freqoccurence of target character
pctfrequency of target character
threeCharthreeChar
This dataframe inclues the usage frequecy and occurence of Chinese word
twoChartwoChar
A data frame with 3 variables:
charactertarget character
freqoccurence of target character
pctfrequency of target character
twoChartwoChar
This is a function that lists the next word appearing frequency by a given chinese character based on real world chinese character frequency Statistics table.
wordMiner.next(candidateWord, topN = 10)wordMiner.next(candidateWord, topN = 10)
candidateWord |
A single Chinese character |
topN |
The number of raws of output dataframe |
A dataframe containing the next word and its occurrence and frequency
## Not run: wordMiner.next(strsplit(levels(twoChar$character)[988], "")[[1]][1]) wordMiner.next(strsplit(levels(twoChar$character)[988], "")[[1]][2], 20) ## End(Not run)## Not run: wordMiner.next(strsplit(levels(twoChar$character)[988], "")[[1]][1]) wordMiner.next(strsplit(levels(twoChar$character)[988], "")[[1]][2], 20) ## End(Not run)
This is a function that lists the previous word appearing frequency by a given chinese character based on real world chinese character frequency Statistics table.
wordMiner.previous(candidateWord, topN = 10)wordMiner.previous(candidateWord, topN = 10)
candidateWord |
A single Chinese character |
topN |
The number of raws of output dataframe |
A dataframe containing the previous word and its occurrence and frequency
## Not run: wordMiner.previous(strsplit(levels(twoChar$character)[988], "")[[1]][1]) wordMiner.previous(strsplit(levels(twoChar$character)[988], "")[[1]][2], 20) ## End(Not run)## Not run: wordMiner.previous(strsplit(levels(twoChar$character)[988], "")[[1]][1]) wordMiner.previous(strsplit(levels(twoChar$character)[988], "")[[1]][2], 20) ## End(Not run)